// Assert functions return if executed without errors

#ifndef ASSERT_OPS_LIBC_H
#define ASSERT_OPS_LIBC_H

#include <poll.h>
#include <stdio.h>
#include <sys/stat.h>

char *assert_aprintf(const char * restrict fmt, ...)
	__attribute__((format(printf, 1, 2), warn_unused_result));
void assert_chdir(const char *path) __attribute__((nonnull));
void assert_close(int fd);
void assert_dup2(int oldfd, int newfd);
void assert_execvp(const char *file, char * const argv[])
	__attribute__((nonnull));
void assert_fchmod(int fd, mode_t mode);
void assert_fclose(FILE *stream);
int assert_fcntl(int fd, int cmd, ...);
FILE *assert_fdopen(int fd, const char *mode)
	__attribute__((warn_unused_result));
void assert_fflush(FILE *stream);
FILE *assert_fopen(const char * restrict path, const char * restrict mode)
	__attribute__((warn_unused_result));
void assert_fprintf(FILE * restrict stream, const char * restrict format, ...)
	__attribute__((format(printf, 2, 3)));
void assert_fputs(const char * restrict s, FILE * restrict stream);
size_t assert_fread(void * restrict ptr, size_t size, size_t nmemb,
	FILE * restrict stream) __attribute__((warn_unused_result));
void assert_fread_noeof(void * restrict ptr, size_t size, size_t nmemb,
	FILE * restrict stream);
void assert_fstat(int fd, struct stat *buf) __attribute__((nonnull));
void assert_futimens(int fd, const struct timespec times[2]);
void assert_fwrite(const void * restrict ptr, size_t size, size_t nmemb,
	FILE * restrict stream);
int assert_getc(FILE *stream);
int assert_getchar(void);
int assert_getchar_noeof(void);
void *assert_malloc(size_t size) __attribute__((malloc, warn_unused_result));
int assert_open(const char *path, int flags, ...) __attribute__((nonnull(1)));
int assert_poll(struct pollfd *fds, nfds_t nfds, int timeout);
void assert_printf(const char * restrict format, ...)
	__attribute__((format(printf, 1, 2)));
void assert_putc(int c, FILE *stream);
void assert_putchar(int c);
void assert_puts(const char *s);
void *assert_realloc(void *ptr, size_t size)
	__attribute__((warn_unused_result));
char *assert_strdup(const char *s) __attribute__((malloc, nonnull));
char *assert_strndup(const char *s, size_t n) __attribute__((malloc, nonnull));
unsigned long int assert_strtoul(const char *nptr, int base)
	__attribute__((nonnull));

#endif
